.. _tutorial:

Tutorial
========

Our tutorial comes in multiple flavours -- pick your flavour of choice!

.. note::

    Currently all our tutorial flavours demonstrate ``charmcraft`` in combination
    with an 12-factor app extension -- a journey that does not require any
    `ops <Operator framework>`_ and which does not currently include publishing the charm. To get a sense of the workflow for other types of applications and including the publication step, see :ref:`manage-charms`.

.. toctree::
    :maxdepth: 2

    write-your-first-kubernetes-charm-for-a-django-app
    flask
    write-your-first-kubernetes-charm-for-a-fastapi-app
    write-your-first-kubernetes-charm-for-a-go-app
